#
# spec file for package pcmciautils
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%if %{undefined _firmwaredir}
%define _firmwaredir /lib/firmware
%endif
%define _udevdir %(pkg-config --variable=udevdir udev)
%define _udevrulesdir %{_udevdir}/rules.d
Name:           pcmciautils
Version:        018
Release:        4.3
Summary:        Utilities for PC-Cards
License:        GPL-2.0-or-later
Group:          Hardware/Other
URL:            https://www.kernel.org/pub/linux/utils/kernel/pcmcia/
Source0:        https://www.kernel.org/pub/linux/utils/kernel/pcmcia/pcmciautils-%{version}.tar.xz
Source1:        suse-files.tar.bz2
Source2:        cis-files.tar.bz2
Patch1:         pcmciautils_config.opts.202500.diff
Patch3:         pcmciautils_pie.diff
Patch4:         fix_udev_directory.patch
Patch5:         instdir.patch
BuildRequires:  bison
BuildRequires:  flex
BuildRequires:  pkgconfig
BuildRequires:  xz
BuildRequires:  pkgconfig(udev) > 187
Requires(pre):  permissions
Supplements:    modalias(pci:v*d*sv*sd*bc06sc07i00*)
Obsoletes:      pcmcia < 017
Provides:       pcmcia >= 017
BuildRequires:  sysfsutils-devel

%description
This package enables the usage of PC-Cards with Linux. It provides
hotplug scripts, and tools that set up sockets and cards. Since kernel
2.6.13 card injection and removal are handled completely via hotplug.
Therefore, a daemon like 'cardmgr' is no longer needed. Soft ejecting
and inserting cards can be done with pccardctl (it was cardctl before).
There are also some tools for debugging and CIS handling.

%prep
%setup -q -n pcmciautils-%{version}
%patch -P 1
%setup -q -n pcmciautils-%{version} -T -D -a 1
%setup -q -n pcmciautils-%{version} -T -D -a 2
%patch -P 3 -p1
%patch -P 4 -p1
%patch -P 5 -p1

%build
make %{?_smp_mflags} all DEF_CFLAGS="-fPIE %{optflags}" DEF_LDFLAGS="-pie" STRIPCMD=true

%install
make DESTDIR=%{buildroot} install %{?_smp_mflags}
install -m 644 suse-files/NOTE %{buildroot}%{_sysconfdir}/pcmcia
mkdir -p %{buildroot}%{_firmwaredir}
# Only install E-CARD.cis, all other files are part of
# kernel-firmware package, so no need to duplicate them.
install -m 644 cis-files/E-CARD.cis %{buildroot}%{_firmwaredir}
mkdir -p %{buildroot}%{_docdir}/pcmciautils
install -m 644 suse-files/README.SUSE %{buildroot}%{_docdir}/pcmciautils

%post
%set_permissions /usr/sbin/pccardctl
rm -vf %{_sysconfdir}/sysconfig/pcmcia

%verifyscript
%verify_permissions -e /usr/sbin/pccardctl

%files
%defattr(-,root,root)
%dir %{_sysconfdir}/pcmcia
%config %{_sysconfdir}/pcmcia/config.opts
%{_sysconfdir}/pcmcia/NOTE
%{_udevrulesdir}/60-pcmcia.rules
%verify(not mode) %attr(4750,root,trusted) /usr/sbin/pccardctl
%{_udevdir}/pcmcia-check-broken-cis
%{_udevdir}/pcmcia-socket-startup
/usr/sbin/lspcmcia
%{_firmwaredir}/*
%{_docdir}/pcmciautils
%{_mandir}/man8/*

%changelog
* Thu Feb 29 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Use %%patch -P N instead of deprecated %%patchN.
* Tue Feb  1 2022 Matthias Gerstner <matthias.gerstner@suse.com>
- instdir.patch: move binaries from /sbin to /usr/sbin, where all binaries
  belong by now. /sbin is a symlink to /usr/sbin so no compatibility issues
  should occur.
* Wed Jun  2 2021 Callum Farmer <gmbr3@opensuse.org>
- Use %%_firmwaredir
* Wed Sep  9 2015 mpluskal@suse.com
- Update to 018
  * no changelog available
- Use url for source
- Update project url
- Remove pcmciautils_fix1.diff (similar fix already included in
  upstream)
- Cleanup spec file with spec-cleaner
* Sun Apr 14 2013 crrodriguez@opensuse.org
- Use pkgconfig to determine the correct path of udev stuff
- Update the bundled udev rules to use the BUILTIN modprobe
  routines instead of invoking the modprobe binary.
* Mon Nov  5 2012 tittiatcoke@gmail.com
- Added patch (fix_udev_directory.patch) to ensure that the udev
  related files are installed in the correct /usr/lib/udev
  directory
* Tue Jan 31 2012 dlovasko@suse.com
- Added patch for platform independent executable build
* Tue Oct 25 2011 ro@suse.de
- null termination of the pccardctl_opts added (bnc#567197)
* Thu Aug 11 2011 aj@suse.de
- Only install E-CARD.cis, all other files are part of kernel-firmware
  package.
- Use set_permissions.
* Thu Nov 11 2010 coolo@novell.com
- fix file list
* Tue Sep  7 2010 aj@suse.de
- BuildRequire sysfsutils-devel
* Tue Jul 20 2010 vbotka@suse.de
- updated to version 017:
  changes against pcmciautils-016
  - Always use path without trailing slash
  - Use architecture-specific config.opts if it exists
  - Add config.opts for hppa
  - Add config.opts for powerpc
  - pcmciautils: improve for cross-builds
  changes against pcmciautils-015
  - Install udev helpers in customizable directory
  - pccardctl: add array out-of-bounds exception
  - fix parallel build of ccdv
- fixed bnc#623638
* Fri Sep 26 2008 seife@suse.de
- add missing directory /lib/udev to filelist to fix build
* Thu Aug 28 2008 vbotka@suse.cz
- updated to version 015:
  - fix for udev-094 or newer
  - improved udev rules
  - status "command" now implemented in pccardctl
  - documentation fixes
- moved udev helpers to /lib/udev/
* Fri Jul 27 2007 zoz@suse.de
- removed usage of hwup/down and sysconfig/pcmcia
  we now use the upstream udev rules for device initialisation
- added upstream patch for udev094 (no more MODALIAS key name)
* Thu Mar 29 2007 rguenther@suse.de
- add bison and flex BuildRequires
* Sun Mar 18 2007 ro@suse.de
- removed directory /lib/firmware from filelist (in filesystem)
* Mon Jan  8 2007 zoz@suse.de
- update to version 014:
  + fix fallthrough from 'pccardctl ls' to 'pccardctl insert'
  + symlink man page too
  + lspcmcia: fix iomem/ioports mixup
  + handle big endian host in dump_cis
  from version 013:
  + check-broken-cis: endless loop
  + updated runtime powermanagement handling
  + add "lspcmcia"
  + pccardctl: return error values from low-level functions
  + pccardctl: don't break lspcmcia if /sys/class/*/*/device is removed
- added comment in config.opts (bug 202500)
* Wed May 24 2006 schwab@suse.de
- Don't strip binaries.
* Thu Mar 30 2006 zoz@suse.de
- added supplement modalias in specfile (Bug 161340)
* Fri Jan 27 2006 zoz@suse.de
- update to version 012:
  + Makefile: fix double prefix
  + Add output for "pccardctl status"
  + pccardctl: do not use deprecated sysfs_read_attribute_value()
  + Add improvements to config.opts from ubuntu/debian
  + Makefile: allow for statically linked binaries
  + Add improvements to config.opts from opensuse
- added some patches from git:
  + avoid endless loop in pcmcia-check-broken-cis
  + fixed some typos in documentation
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Thu Dec 15 2005 zoz@suse.de
- update to version 011 (we still use our own udev rules)
- removed hotplug/*rc files
* Mon Sep  5 2005 zoz@suse.de
- removed obsolete /etc/hotplug/*agent
- changed io ranges in config.opts due to experience with pcmcia_cs
  and current bugs (97859, 105218)
- pcmcia and pcmcia_socket events wont be handled if /dev/shm/nopcmcia
  exists (will be written with boot option 'pcmcia=off')
- Finally wrote README.SUSE
* Fri Aug 26 2005 kukuk@suse.de
- Provide pcmcia package to enable package at update
- Remove duplicate PreReq
* Mon Aug 22 2005 zozl@suse.de
- added cis files to package, install them to /lib/firmware
- added hwup function files
- changed /etc/hotplug/*rc: they call now hwup directly
- replaced *agent with hwup
- added /etc/sysconfig/pcmcia
* Mon Aug 15 2005 kkeil@suse.de
- add label to support ISDN PCMCIA hotplug via udev (#102342)
* Thu Aug  4 2005 ro@suse.de
- fix permissions handling
- build as non-root
* Mon Aug  1 2005 zoz@suse.de
- added /etc/udev to filelist
* Mon Aug  1 2005 zoz@suse.de
- added /etc/udev/rules.d/50-pcmcia.rules
* Sat Jul 30 2005 zoz@suse.de
- initial package, version 007 (with the license to kill cardmgr ;)
- hotplug *.rc scripts: call *.agent directly; we don't have /sbin/hotplug
- pcmcia_socket.agent: also load module pcmcia
